package com.hungraim.ltc.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.hungraim.ltc.pojo.entity.eval.ChAprEmp;
import com.hungraim.ltc.pojo.vo.assessment.TaskDistributionVO;
import com.hungraim.ltc.pojo.vo.assessment.TaskReportVO;
import com.hungraim.ltc.service.TaskService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 失能评定Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.assessment/task")
@Slf4j
public class TaskController {

    @Autowired
    private TaskService taskService;

    /**
     * 评定任务分配、查询列表
     *
     * @param organId       适用机构代码
     * @param provincial    所在省
     * @param city          所在市
     * @param area          所在区域
     * @param street        所在街道
     * @param realName      失能人员姓名
     * @param certiCode     失能人员身份证号码
     * @param taskName      评定人员姓名
     * @param taskTel       评定人员手机号码
     * @param daysRemaining 评定剩余天数
     * @param status        任务状态
     * @param isReturn      是否退回
     * @param pageNum       当前页
     * @param pageSize      每页几条数据
     */
    @RequestMapping("/taskDistributionList")
    public Result<List<TaskDistributionVO>> taskDistributionList(String organId, String provincial, String city,
                                                                 String street, String realName, String certiCode, String taskName, String taskTel,
                                                                 String daysRemaining, String status, String isReturn, String area,
                                                                 int pageNum, int pageSize) {
        IPage<TaskDistributionVO> iPage = taskService.taskDistributionList(organId, provincial, city,
                street, realName, certiCode, taskName, taskTel, daysRemaining, status, isReturn, area,
                pageNum, pageSize);
        return Result.success(iPage.getRecords());
    }

    /**
     * 评定报告录入列表
     *
     * @param name      失能人员姓名
     * @param certiCode 失能人员身份证号码
     * @param tel       失能人员手机号码
     */
    @RequestMapping("/taskReportList")
    public Result<List<TaskReportVO>> taskReportList(String name, String certiCode, String tel) {
        List<TaskReportVO> taskReportList = taskService.taskReportList(name, certiCode, tel);
        return Result.success(taskReportList);
    }

    /**
     * 查询评定人员列表
     *
     * @param organId 人员所属机构id
     */
    @RequestMapping("/aprEmpList")
    public Result<List<ChAprEmp>> aprEmpList(Integer organId) {
        List<ChAprEmp> chAprEmps = taskService.aprEmpList(organId);
        return Result.success(chAprEmps);
    }

    /**
     * 评定报告新增
     *
     * @param taskId         评定报告id
     * @param person1        鉴定人员1id
     * @param person2        鉴定人员2id
     * @param person3        鉴定人员3id
     * @param disableLevelId 失能等级id
     * @param polNo          保单号
     * @param remark         备注
     */
    @RequestMapping("/addReport")
    public Result addReport(Integer taskId, Integer person1, Integer person2, Integer person3, Integer disableLevelId, String polNo, String remark) {
        taskService.addReport(taskId, person1, person2, person3, disableLevelId, polNo, remark);
        return Result.success();
    }

    /**
     * 评定报告修改
     *
     * @param reportId       评定报告id
     * @param person1        鉴定人员1id
     * @param person2        鉴定人员2id
     * @param person3        鉴定人员3id
     * @param disableLevelId 失能等级id
     * @param polNo          保单号
     * @param remark         备注
     */
    @RequestMapping("/updateReport")
    public Result updateReport(Integer reportId, Integer person1, Integer person2, Integer person3, Integer disableLevelId, String polNo, String remark) {
        if (disableLevelId == null) {
            return Result.failed("失能等级不能为空!");
        }
        if (polNo == null) {
            polNo = "";
        }
        if (remark == null) {
            remark = "";
        }
        taskService.updateReport(reportId, person1, person2, person3, disableLevelId, polNo, remark);
        return Result.success();
    }

    /**
     * 评定任务分配
     *
     * @param taskId 评定任务id
     * @param empId  评定人员id
     */
    @RequestMapping("/allotTask")
    public Result allotTask(String taskId, Integer empId) {
        if (StringUtils.isBlank(taskId)) {
            return Result.failed("id不能为空!");
        }
        Result<Object> objectResult = taskService.allotTask(taskId, empId);
        if (!"0".equals(objectResult.getCode())) {
            //失败
            return Result.failed(objectResult.getMsg());
        }
        return Result.success();
    }

}
